function [P2,T2,W,P] = sprezarka_st(P1,T1,m1,Pist,e_st)

% funkcja do obliczania dla pojedynczego stopnia sprężarki, lub dlo 
% obliczeń sprężarki:
% [P2,T2,W,P] = sprezarka_st(P1,T1,m1,Pist,e_st)
% DANE WEJŚCIOWE
% P1 - ciśnienie całkowite na wejściu do stopnia sprężarki/Spręeżarki
% T1 - temperatura całkowita na wejściu do stopnia sprężarki/Sprężarki
% m1 wydatek powietrza na wejściu do stopnia sprężarki/Sprężarki
% Pist - spręż stopni sprężarkie / Sprężarki 
% e_st - sprawność stopnia sprężarki/sprężarki
%
% DANE WYJŚCIOWE
% P2 - ciśnienie całkowite za stopniem sprężarki/sprężarką
% T2 - Temperatura całkowita za stopniem sprężarki / sprężarką
% W - Praca stopnia / sprężarki
% P - Moc stopnia / sprężarki


% DEfinicja włąściwości gazu
k=1.4;
cp=1005;

% Obliczenia parametrów za stopniem sprężarki/sprężarką
P2=P1*Pist;
T2=T1*(1+(Pist.^((k-1)/k)-1)/e_st);
W=cp*(T2-T1);
P=m1*W;
end

